.. _spkg_chardet:

chardet: Universal encoding detector for Python 3
=================================================

Description
-----------

Universal encoding detector for Python 3

License
-------

LGPL

Upstream Contact
----------------

https://pypi.org/project/chardet/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    5.2.0

version_requirements.txt::

    chardet

Equivalent System Packages
--------------------------

(none known)
